using WorkFlowCheck.Common.DTO;

namespace WorkFlowCheck.Web.Services.Interfaces
{
    public interface ISystemService
    {
        Task<List<ImageFileDTO>> GetAllImageFilesAsync();
        Task<ApiResponseDTO<byte[]>> DownloadFile(string filename);
        
        Task<List<PDFFileDTO>> GetAllPDFFilesAsync();
        Task<ApiResponseDTO<byte[]>> DownloadPDFFile(string filename);

        Task<List<LogFileDTO>> GetAllLogAuditFilesAsync();
        Task<ApiResponseDTO<byte[]>> DownloadAuditLogFile(string filename);

        Task<List<LogFileDTO>> GetAllLogBusinessFilesAsync();
        Task<ApiResponseDTO<byte[]>> DownloadBusinessLogFile(string filename);

    }
}
